@@ -1,7 +1,10 @@
 // =====================================================================
-//  $Id: TOutputStream.cc,v 1.2 2004/06/28 04:02:50 goiwai Exp $
-//  $Name: CLDAQ-1-14-01 $
+//  $Id: TOutputStream.cc,v 1.3 2004/06/28 04:50:30 goiwai Exp $
+//  $Name: CLDAQ-1-14-02 $
 //  $Log: TOutputStream.cc,v $
+//  Revision 1.3  2004/06/28 04:50:30  goiwai
+//  GetLogLevel()ɲäޤ
+//
 //  Revision 1.2  2004/06/28 04:02:50  goiwai
 //  TlogTclogѹ
 //
@@ -23,6 +26,11 @@ void TOutputStream::SetLogLevel( int level )
   return;
 }
 
+int TOutputStream::GetLogLevel() const
+{
+  return ( (TStringStreamBuffer*)_M_streambuf ) -> GetLogLevel();
+}
+
 TOutputStream Tcout( &coutbuf );
 TOutputStream Tcerr( &cerrbuf );
 TOutputStream Tclog( &clogbuf );
